#line 2 "scanaut.cc"
#include "config.h"
/* Flex 2.6.4's test for <inttypes.h> relies on __STDC_VERSION__
   which is undefined in C++.   So without that, it will define
   its own integer types, including a broken SIZE_MAX definition.
   So let's define __STDC_VERSION__ to make sure <inttypes.h> gets
   included. */
#if HAVE_INTTYPES_H && !(defined __STDC_VERSION__)
#  define __STDC_VERSION__ 199901L
#endif

#line 13 "scanaut.cc"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define hoayy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer hoayy_create_buffer
#endif

#ifdef yy_delete_buffer
#define hoayy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer hoayy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define hoayy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer hoayy_scan_buffer
#endif

#ifdef yy_scan_string
#define hoayy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string hoayy_scan_string
#endif

#ifdef yy_scan_bytes
#define hoayy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes hoayy_scan_bytes
#endif

#ifdef yy_init_buffer
#define hoayy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer hoayy_init_buffer
#endif

#ifdef yy_flush_buffer
#define hoayy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer hoayy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define hoayy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state hoayy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define hoayy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer hoayy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define hoayypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state hoayypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define hoayypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state hoayypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define hoayyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack hoayyensure_buffer_stack
#endif

#ifdef yylex
#define hoayylex_ALREADY_DEFINED
#else
#define yylex hoayylex
#endif

#ifdef yyrestart
#define hoayyrestart_ALREADY_DEFINED
#else
#define yyrestart hoayyrestart
#endif

#ifdef yylex_init
#define hoayylex_init_ALREADY_DEFINED
#else
#define yylex_init hoayylex_init
#endif

#ifdef yylex_init_extra
#define hoayylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra hoayylex_init_extra
#endif

#ifdef yylex_destroy
#define hoayylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy hoayylex_destroy
#endif

#ifdef yyget_debug
#define hoayyget_debug_ALREADY_DEFINED
#else
#define yyget_debug hoayyget_debug
#endif

#ifdef yyset_debug
#define hoayyset_debug_ALREADY_DEFINED
#else
#define yyset_debug hoayyset_debug
#endif

#ifdef yyget_extra
#define hoayyget_extra_ALREADY_DEFINED
#else
#define yyget_extra hoayyget_extra
#endif

#ifdef yyset_extra
#define hoayyset_extra_ALREADY_DEFINED
#else
#define yyset_extra hoayyset_extra
#endif

#ifdef yyget_in
#define hoayyget_in_ALREADY_DEFINED
#else
#define yyget_in hoayyget_in
#endif

#ifdef yyset_in
#define hoayyset_in_ALREADY_DEFINED
#else
#define yyset_in hoayyset_in
#endif

#ifdef yyget_out
#define hoayyget_out_ALREADY_DEFINED
#else
#define yyget_out hoayyget_out
#endif

#ifdef yyset_out
#define hoayyset_out_ALREADY_DEFINED
#else
#define yyset_out hoayyset_out
#endif

#ifdef yyget_leng
#define hoayyget_leng_ALREADY_DEFINED
#else
#define yyget_leng hoayyget_leng
#endif

#ifdef yyget_text
#define hoayyget_text_ALREADY_DEFINED
#else
#define yyget_text hoayyget_text
#endif

#ifdef yyget_lineno
#define hoayyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno hoayyget_lineno
#endif

#ifdef yyset_lineno
#define hoayyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno hoayyset_lineno
#endif

#ifdef yyget_column
#define hoayyget_column_ALREADY_DEFINED
#else
#define yyget_column hoayyget_column
#endif

#ifdef yyset_column
#define hoayyset_column_ALREADY_DEFINED
#else
#define yyset_column hoayyset_column
#endif

#ifdef yywrap
#define hoayywrap_ALREADY_DEFINED
#else
#define yywrap hoayywrap
#endif

#ifdef yyalloc
#define hoayyalloc_ALREADY_DEFINED
#else
#define yyalloc hoayyalloc
#endif

#ifdef yyrealloc
#define hoayyrealloc_ALREADY_DEFINED
#else
#define yyrealloc hoayyrealloc
#endif

#ifdef yyfree
#define hoayyfree_ALREADY_DEFINED
#else
#define yyfree hoayyfree
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin , yyscanner )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void yyrestart ( FILE *input_file , yyscan_t yyscanner );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size , yyscan_t yyscanner );
void yy_delete_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yy_flush_buffer ( YY_BUFFER_STATE b , yyscan_t yyscanner );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer , yyscan_t yyscanner );
void yypop_buffer_state ( yyscan_t yyscanner );

static void yyensure_buffer_stack ( yyscan_t yyscanner );
static void yy_load_buffer_state ( yyscan_t yyscanner );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file , yyscan_t yyscanner );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER , yyscanner)

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str , yyscan_t yyscanner );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len , yyscan_t yyscanner );

void *yyalloc ( yy_size_t , yyscan_t yyscanner );
void *yyrealloc ( void *, yy_size_t , yyscan_t yyscanner );
void yyfree ( void * , yyscan_t yyscanner );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define hoayywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state ( yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  , yyscan_t yyscanner);
static int yy_get_next_buffer ( yyscan_t yyscanner );
static void yynoreturn yy_fatal_error ( const char* msg , yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;
#define YY_NUM_RULES 95
#define YY_END_OF_BUFFER 96
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[432] =
    {   0,
        0,    0,   76,   76,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   74,   74,    0,    0,   96,   94,
        3,    1,    1,   82,   94,   94,   94,   94,   94,   94,
       94,   76,   79,   79,   78,   77,   87,   84,   84,   83,
       95,   93,   91,   91,   88,   90,   30,   94,   34,   94,
       31,   31,   31,   29,   31,   31,   30,   31,   31,   31,
       30,   94,   62,   94,   59,   63,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   65,   66,   67,   94,   70,
       94,   72,   94,   68,   74,    3,   74,   74,    1,    1,

       94,   94,   48,   94,   94,   94,   94,   94,   94,   94,
       94,    3,    1,    2,    2,    1,    0,    0,    4,    0,
        0,    0,    0,    0,    0,   76,   79,   80,   80,   79,
       81,   77,   75,   87,   84,   85,   85,   84,   86,   93,
       91,   92,   92,   91,    0,    0,    0,    0,   35,   33,
       31,   32,   31,   31,   31,   31,    0,   31,   31,   31,
       31,   31,   31,    0,   62,   57,   64,   64,   64,   55,
       64,   54,   64,   53,   56,   64,   64,   65,   65,   66,
       71,   70,   73,   72,   69,   68,   74,    3,    4,    1,
        2,    0,    0,    0,    2,    1,    0,   44,   49,    0,

        0,    0,    0,    0,    0,    0,    0,    0,   41,    0,
        0,    0,    0,   11,   10,    9,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,   36,   14,   31,
       31,   31,   28,   31,   31,   31,   31,   31,   31,   64,
       64,   64,   64,   64,   64,    0,    0,    0,    0,    0,
        0,   47,   44,   50,   40,    0,    0,   51,    0,    0,
        0,    0,    0,    0,   11,    6,    0,    0,   89,    0,
        0,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   64,   64,   64,   58,   52,   63,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    8,    0,    0,   31,

       31,   31,   31,   31,   31,   20,   31,   31,   31,   19,
       64,   64,   59,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   31,   15,   13,   27,   31,   31,   31,
       31,   31,   31,   61,   60,    0,    0,    0,   39,   38,
        0,    0,    0,    0,    0,   26,   31,   12,   31,   31,
       31,   31,   31,    0,    0,    0,   37,    0,    0,    0,
       25,   31,   31,   31,   31,   31,   31,   46,    0,   43,
       42,    0,    7,   31,   17,   31,   31,   31,   31,    0,
       43,    0,    5,   31,   31,   31,   31,   31,    0,   16,
       31,   21,   31,   31,    0,   31,   31,   31,    0,   31,

       31,   31,    0,   31,   31,   31,    0,   31,   31,   31,
        0,   18,   31,   31,   31,    0,   31,   31,   31,   45,
       24,   31,   31,   31,   31,   31,   31,   23,   31,   22,
        0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    5,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    6,    7,    8,    1,    1,    9,    1,   10,
       11,   12,    1,    1,   13,   14,   15,   16,   17,   18,
       19,   19,   19,   19,   19,   19,   19,   20,    1,    1,
        1,   21,    1,   22,   23,   24,   25,   26,   27,   28,
       28,   29,   28,   28,   28,   28,   28,   30,   31,   32,
       28,   33,   34,   35,   28,   28,   28,   28,   36,   28,
       37,   38,   39,    1,   40,    1,   41,   42,   43,   44,

       45,   46,   47,   48,   49,   28,   50,   51,   52,   53,
       54,   55,   28,   56,   57,   58,   59,   60,   28,   61,
       62,   28,   63,   64,   63,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[65] =
    {   0,
        1,    1,    2,    1,    3,    1,    4,    1,    1,    5,
        5,    6,    7,    7,    6,    8,    8,    8,    8,    9,
        1,    1,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,    8,    8,    8,    8,   10,    4,   10,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,    8,    8,    8,    8,    8,    8,    8,    8,
        8,    8,    1,    1
    } ;

static const flex_int16_t yy_base[450] =
    {   0,
        0,   52,    9,   20,   34,   35,   17,   40,  105,    0,
      169,    0,  226,  240,  254,  268,   59,   80,  282,  296,
      310,  324,  338,  352,   86,  380,  403,    0, 1029, 1030,
        7,   28,   31, 1030,  977, 1014, 1014,  356,   13,  994,
      979,    0,   74,   89, 1008, 1010,    0,   95,   99, 1030,
        0,    0,  232,  233, 1030,  238, 1030, 1008,  380,    0,
      231, 1000,   28,    0,   60,  221,  999,  248,  240,  283,
      234,   42, 1030,  997, 1030, 1030,    0,  192,  963,  275,
      962,  969,  970,  963,  956,  384,  396, 1030,  994,  417,
      993,  427,  992,  433,    0,  315,    0,  996,  435,  450,

      994,  249,  441,  288,  952,  244,  974,  946,  942,  957,
      983,  343,  997,  996,  993,  992,  947,  972, 1030,  449,
      467,  971,  970,  969,  931,    0,  987,  986,  983,  982,
     1030,  974, 1030,    0,  982,  981,  978,  977, 1030,    0,
      978,  977,  974,  973,  408,  968,  912,  365,  473,    0,
      955, 1030,  954,  290,  285,  339,  934,  366,  341,  310,
      370,  373,  419,  342, 1030, 1030,    0,  915,  917,    0,
      919,    0,  911,    0,    0,  919,  908,  477,  234,  481,
     1030,  488, 1030,  492, 1030,  496,    0,  421,    0,  513,
      514,  397,  935,  920,  518,  519,  951,    0,  509,  943,

      919,  909,  937,  936,  935,  916,  901,  895, 1030,  949,
      950,  899,  927,  533, 1030, 1030,  930,  904,  943,  944,
      941,  942,  939,  940,  468,  911,  911,  513, 1030,  359,
      434,  500, 1030,  467,  516,  457,  427,  517,  356,  895,
      887,  881,  883,  881,  890,  550,  554,  558,  559,  589,
      590, 1030,    0,  580, 1030,  488,  882, 1030,  913,  512,
      881,  886,  885,  898, 1030, 1030,  872,  563, 1030,  901,
      900,  526,  521,  562,  557,  569,  580,  905,  581,  610,
      904,  867,  873,  876,    0,    0,    0,  886,  864,  873,
      851,  854,  840,  824,  877,  838, 1030,  834,  845,  586,

      836,  835,  584,  588,  585, 1030,  589,  590,  601, 1030,
      787,  794,    0,  787,  777,  773,  805,  593,  776,  615,
      781,  802,  749,  594, 1030, 1030, 1030,  739,  534,  605,
      607,  608,  618,    0,    0,  711,  716,  698, 1030, 1030,
      735,  705,  635,  740,  739, 1030,  620, 1030,  626,  628,
      635,  637,  639,  731,  697,  729, 1030,  688,  661,  732,
     1030,  640,  721,  641,  642,  644,   10, 1030,  696,    0,
     1030,  731, 1030,  649, 1030,  518,  650,  652,  654,  690,
        0,  727, 1030,  712,  655,  711,  668,  660,  717, 1030,
      656, 1030,  657,  669,  697,  672,  670,  671,  686,  673,

      679,  675,  432,  678,  286,  694,  415,  442,  680,  683,
      309, 1030,  691,  693,  684,  245,  226,  697,  695, 1030,
     1030,  698,  702,  704,  703,   79,  706, 1030,   29, 1030,
     1030,  763,  773,  783,  793,  803,  813,  823,  833,  843,
      853,  857,  859,  868,    2,  877,  887,  897,  907
    } ;

static const flex_int16_t yy_def[450] =
    {   0,
      432,  432,  433,  433,  434,  434,  435,  435,  431,    9,
      431,   11,    2,    2,    2,    2,  432,  432,    2,    2,
        2,    2,    2,    2,  436,  436,    2,   27,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  437,  431,  431,  431,  438,  439,  431,  431,  431,
      440,  441,  431,  431,  431,  431,  431,  431,  431,  442,
      443,  443,  443,  444,  443,  443,  443,  443,  443,  443,
      443,  431,  431,  431,  431,  431,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  446,  446,  446,  446,  431,  431,

      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  437,  431,  431,  431,  431,
      431,  438,  431,  439,  431,  431,  431,  431,  431,  441,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  442,
      443,  431,  443,  443,  443,  443,  444,  443,  443,  443,
      443,  443,  443,  431,  431,  431,  445,  445,  445,  445,
      445,  445,  445,  445,  445,  445,  445,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  446,  446,  446,  431,
      431,  431,  431,  431,  431,  431,  431,  447,  431,  431,

      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  443,
      443,  443,  431,  443,  443,  443,  443,  443,  443,  445,
      445,  445,  445,  445,  445,  431,  431,  431,  431,  431,
      431,  431,  447,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  443,  443,  443,  443,  443,  443,  443,  443,  443,
      443,  445,  445,  445,  445,  445,  445,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  443,

      443,  443,  443,  443,  443,  431,  443,  443,  443,  431,
      445,  445,  445,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  443,  431,  431,  431,  443,  443,  443,
      443,  443,  443,  445,  445,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  443,  431,  443,  443,
      443,  443,  443,  431,  431,  431,  431,  431,  431,  431,
      431,  443,  443,  443,  443,  443,  443,  431,  431,  448,
      431,  449,  431,  443,  431,  443,  443,  443,  443,  431,
      448,  449,  431,  443,  443,  443,  443,  443,  431,  431,
      443,  431,  443,  443,  431,  443,  443,  443,  431,  443,

      443,  443,  431,  443,  443,  443,  431,  443,  443,  443,
      431,  431,  443,  443,  443,  431,  443,  443,  443,  431,
      431,  443,  443,  443,  443,  443,  443,  431,  443,  431,
        0,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431
    } ;

static const flex_int16_t yy_nxt[1095] =
    {   0,
      431,   31,   32,   31,   33,  431,   34,   35,  112,  167,
      112,   43,   36,   44,   37,   38,   38,   38,   38,   53,
       45,   54,   43,   46,   44,   39,   55,   56,   40,  152,
      113,   45,  114,  115,   46,  116,   48,   48,   49,   49,
       50,   50,   53,  164,   54,  122,  123,  152,  430,   55,
       56,  165,   41,   31,   32,   31,   33,  379,   34,   35,
       31,   32,   31,   33,   36,   34,   37,   38,   38,   38,
       38,   51,   51,   37,   88,   88,  127,   39,  128,  152,
       40,   31,   32,   31,   33,  156,   34,   96,   32,   96,
       33,  129,   97,  130,   37,   88,   88,  135,  428,  136,

       98,  137,  158,  138,   41,   30,   31,   32,   31,   33,
       57,   34,   30,   57,   57,   57,   30,   58,   30,   37,
       59,   59,   59,   59,   30,   30,   60,   61,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   63,   62,
       62,   64,   30,   57,   62,   65,   62,   66,   62,   62,
       67,   62,   62,   62,   62,   62,   62,   68,   62,   69,
       62,   70,   71,   62,   62,   62,   62,   57,   57,   30,
       31,   32,   31,   33,   72,   34,   30,   30,   73,   30,
       30,   74,   30,   37,   75,   76,   30,   30,   30,   30,
       30,   77,   77,   77,   77,   77,   77,   77,   77,   77,

       77,   77,   77,   77,   77,   30,   30,   30,   30,   78,
       77,   77,   79,   77,   80,   81,   77,   82,   77,   77,
       77,   77,   83,   77,   77,   84,   85,   77,   77,   77,
       77,   30,   30,   30,  141,  143,  142,  144,   30,  145,
      152,   86,   86,   86,   86,  421,  146,   30,  168,  169,
      152,   30,   30,  152,   30,   86,   86,   86,   86,  152,
      119,   30,  153,  198,  420,   30,   30,  152,   30,   87,
       87,   87,   87,  154,  159,   30,  203,  204,   30,   30,
       30,  155,   30,   87,   87,   87,   87,  163,  160,   30,
      179,  179,   30,   30,   89,  161,   30,   90,   90,   90,

       90,  147,  152,   30,  152,  152,   30,   30,   89,  152,
       30,   90,   90,   90,   90,  171,  188,   30,  188,  200,
       30,   30,   91,  172,   30,   92,   92,   92,   92,  152,
      201,   30,  230,  231,   30,   30,   91,  162,   30,   92,
       92,   92,   92,  164,  112,   30,  112,  409,   30,   30,
       93,  165,   30,   94,   94,   94,   94,  120,  152,   30,
      152,  236,   30,   30,   93,  416,   30,   94,   94,   94,
       94,  121,  121,  121,  121,  152,   30,   30,  152,  232,
       30,   96,   32,   96,   33,  152,   97,  213,  226,  152,
       30,  227,  152,  235,   98,  149,  149,  149,  149,  178,

      178,  178,  178,  272,   30,   99,  281,  100,  234,  145,
       30,  180,  180,  180,  180,  101,  146,  102,  103,  103,
      103,  103,  188,  237,  188,  104,  238,  105,  106,  203,
      204,  107,  182,  182,  182,  182,  108,  190,  152,  191,
      179,  179,  184,  184,  184,  184,  152,  109,  186,  186,
      186,  186,  195,  152,  196,  110,  199,  199,  199,  199,
      192,  412,  111,  193,  214,  214,  214,  214,  120,  268,
      411,  147,  239,  268,  273,  192,  152,  269,  193,  276,
      407,  279,  121,  121,  121,  121,  152,  194,  228,  228,
      228,  228,  178,  178,  178,  178,  180,  180,  180,  180,

      288,  278,  194,  182,  182,  182,  182,  184,  184,  184,
      184,  186,  186,  186,  186,  190,  247,  246,  248,  152,
      249,  251,  250,  196,  254,  254,  254,  254,  228,  228,
      228,  228,  289,  179,  179,  152,  152,  152,  192,  192,
      152,  193,  193,  192,  192,  152,  193,  193,  214,  214,
      214,  214,  251,  152,  248,  274,  249,  275,  191,  385,
      251,  249,  248,  246,  268,  194,  194,  291,  268,  292,
      194,  194,  269,  277,  280,  192,  152,  301,  193,  192,
      300,  152,  193,  192,  192,  349,  193,  193,  152,  265,
      265,  195,  249,  248,  246,  254,  254,  254,  254,  152,

      152,  303,  194,  327,  152,  152,  194,  152,  152,  152,
      194,  194,  340,  152,  192,  192,  320,  193,  193,  302,
      152,  304,  308,  309,  152,  307,  152,  152,  329,  152,
      343,  343,  343,  343,  347,  305,  359,  152,  330,  152,
      328,  194,  194,  324,  331,  152,  332,  152,  333,  341,
      343,  343,  343,  343,  152,  350,  152,  332,  152,  152,
      152,  152,  359,  152,  351,  352,  353,  372,  152,  152,
      363,  152,  362,  152,  152,  152,  152,  366,  364,  152,
      393,  376,  374,  365,  400,  367,  377,  152,  152,  152,
      152,  152,  152,  384,  152,  404,  387,  152,  152,  152,

      396,  378,  152,  152,  388,  391,  386,  410,  394,  408,
      152,  397,  152,  152,  152,  398,  152,  152,  402,  405,
      401,  152,  152,  152,  413,  152,  403,  414,  399,  395,
      392,  390,  406,  383,  389,  423,  418,  383,  380,  415,
      375,  419,  424,  422,  373,  371,  417,  427,  370,  369,
      368,  361,  360,  358,  357,  356,  355,  354,  348,  425,
      426,  346,  429,   30,   30,   30,   30,   30,   30,   30,
       30,   30,   30,   42,   42,   42,   42,   42,   42,   42,
       42,   42,   42,   47,   47,   47,   47,   47,   47,   47,
       47,   47,   47,   52,   52,   52,   52,   52,   52,   52,

       52,   52,   52,   95,   95,   95,   95,   95,   95,   95,
       95,   95,   95,  126,  345,  344,  126,  126,  342,  126,
      126,  126,  126,  132,  339,  338,  132,  132,  132,  132,
      132,  132,  132,  134,  337,  336,  335,  134,  134,  134,
      134,  134,  134,  139,  334,  139,  139,  139,  139,  139,
      139,  139,  139,  140,  326,  325,  140,  323,  140,  140,
      140,  140,  140,  150,  150,  151,  151,  151,  157,  322,
      321,  157,  157,  157,  157,  157,  157,  187,  320,  258,
      187,  187,  187,  187,  187,  187,  187,  253,  319,  253,
      253,  253,  253,  253,  253,  253,  253,  381,  318,  381,

      381,  381,  381,  381,  381,  381,  381,  382,  317,  382,
      382,  382,  382,  382,  382,  382,  382,  316,  315,  314,
      313,  312,  311,  310,  306,  299,  298,  297,  296,  295,
      294,  293,  258,  290,  287,  286,  285,  284,  283,  282,
      271,  270,  143,  142,  137,  136,  129,  128,  267,  266,
      264,  263,  115,  114,  262,  261,  260,  259,  258,  258,
      257,  256,  255,  252,  208,  205,  245,  244,  243,  242,
      241,  240,  233,  229,  152,  225,  225,  144,  224,  223,
      141,  138,  222,  221,  135,  431,  130,  220,  219,  127,
      218,  217,  216,  215,  213,  212,  116,  211,  210,  113,

      209,  208,  207,  206,  205,  202,  197,  189,  185,  183,
      181,  177,  176,  175,  174,  173,  170,  166,  152,  152,
      148,  133,  131,  125,  124,  119,  118,  117,  431,   29,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431

    } ;

static const flex_int16_t yy_chk[1095] =
    {   0,
        0,    1,    1,    1,    1,    0,    1,    1,   31,  445,
       31,    3,    1,    3,    1,    1,    1,    1,    1,    7,
        3,    7,    4,    3,    4,    1,    7,    7,    1,  367,
       32,    4,   32,   33,    4,   33,    5,    6,    5,    6,
        5,    6,    8,   72,    8,   39,   39,   63,  429,    8,
        8,   72,    1,    2,    2,    2,    2,  367,    2,    2,
       17,   17,   17,   17,    2,   17,    2,    2,    2,    2,
        2,    5,    6,   17,   17,   17,   43,    2,   43,   65,
        2,   18,   18,   18,   18,   63,   18,   25,   25,   25,
       25,   44,   25,   44,   18,   18,   18,   48,  426,   48,

       25,   49,   65,   49,    2,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   13,   53,   54,   53,   54,   13,   56,
       66,   13,   13,   13,   13,  417,   56,   14,   78,   78,
       61,   13,   14,   71,   13,   14,   14,   14,   14,   69,
      102,   15,   61,  102,  416,   14,   15,   68,   14,   15,
       15,   15,   15,   61,   66,   16,  106,  106,   13,   15,
       16,   61,   15,   16,   16,   16,   16,   71,   68,   19,
      179,  179,   14,   16,   19,   69,   16,   19,   19,   19,

       19,   56,   70,   20,  155,  405,   15,   19,   20,  154,
       19,   20,   20,   20,   20,   80,   96,   21,   96,  104,
       16,   20,   21,   80,   20,   21,   21,   21,   21,  160,
      104,   22,  154,  155,   19,   21,   22,   70,   21,   22,
       22,   22,   22,  164,  112,   23,  112,  405,   20,   22,
       23,  164,   22,   23,   23,   23,   23,   38,  156,   24,
      159,  160,   21,   23,   24,  411,   23,   24,   24,   24,
       24,   38,   38,   38,   38,  239,   22,   24,  230,  156,
       24,   26,   26,   26,   26,  158,   26,  148,  148,  161,
       23,  148,  162,  159,   26,   59,   59,   59,   59,   86,

       86,   86,   86,  230,   24,   27,  239,   27,  158,  145,
       27,   87,   87,   87,   87,   27,  145,   27,   27,   27,
       27,   27,  188,  161,  188,   27,  162,   27,   27,  192,
      192,   27,   90,   90,   90,   90,   27,   99,  163,   99,
       86,   86,   92,   92,   92,   92,  237,   27,   94,   94,
       94,   94,  100,  231,  100,   27,  103,  103,  103,  103,
       99,  408,   27,   99,  120,  120,  120,  120,  121,  225,
      407,  145,  163,  225,  231,  100,  236,  225,  100,  234,
      403,  237,  121,  121,  121,  121,  234,   99,  149,  149,
      149,  149,  178,  178,  178,  178,  180,  180,  180,  180,

      256,  236,  100,  182,  182,  182,  182,  184,  184,  184,
      184,  186,  186,  186,  186,  190,  191,  190,  191,  232,
      195,  196,  195,  196,  199,  199,  199,  199,  228,  228,
      228,  228,  256,  178,  178,  235,  238,  376,  190,  191,
      273,  190,  191,  195,  196,  272,  195,  196,  214,  214,
      214,  214,  246,  329,  246,  232,  247,  232,  247,  376,
      248,  249,  248,  249,  268,  190,  191,  260,  268,  260,
      195,  196,  268,  235,  238,  246,  275,  273,  246,  247,
      272,  274,  247,  248,  249,  329,  248,  249,  276,  214,
      214,  250,  251,  250,  251,  254,  254,  254,  254,  277,

      279,  275,  246,  303,  305,  300,  247,  304,  307,  308,
      248,  249,  318,  324,  250,  251,  320,  250,  251,  274,
      309,  276,  280,  280,  330,  279,  331,  332,  304,  280,
      320,  320,  320,  320,  324,  277,  343,  333,  305,  347,
      303,  250,  251,  300,  307,  349,  308,  350,  309,  318,
      343,  343,  343,  343,  351,  330,  352,  309,  353,  362,
      364,  365,  359,  366,  331,  332,  333,  359,  374,  377,
      349,  378,  347,  379,  385,  391,  393,  352,  350,  388,
      387,  364,  362,  351,  396,  353,  365,  387,  394,  397,
      398,  396,  400,  374,  402,  400,  378,  404,  401,  409,

      391,  366,  410,  415,  379,  385,  377,  406,  388,  404,
      413,  393,  414,  406,  419,  394,  418,  422,  398,  401,
      397,  423,  425,  424,  409,  427,  399,  410,  395,  389,
      386,  384,  402,  382,  380,  419,  414,  372,  369,  410,
      363,  415,  422,  418,  360,  358,  413,  425,  356,  355,
      354,  345,  344,  342,  341,  338,  337,  336,  328,  423,
      424,  323,  427,  432,  432,  432,  432,  432,  432,  432,
      432,  432,  432,  433,  433,  433,  433,  433,  433,  433,
      433,  433,  433,  434,  434,  434,  434,  434,  434,  434,
      434,  434,  434,  435,  435,  435,  435,  435,  435,  435,

      435,  435,  435,  436,  436,  436,  436,  436,  436,  436,
      436,  436,  436,  437,  322,  321,  437,  437,  319,  437,
      437,  437,  437,  438,  317,  316,  438,  438,  438,  438,
      438,  438,  438,  439,  315,  314,  312,  439,  439,  439,
      439,  439,  439,  440,  311,  440,  440,  440,  440,  440,
      440,  440,  440,  441,  302,  301,  441,  299,  441,  441,
      441,  441,  441,  442,  442,  443,  443,  443,  444,  298,
      296,  444,  444,  444,  444,  444,  444,  446,  295,  294,
      446,  446,  446,  446,  446,  446,  446,  447,  293,  447,
      447,  447,  447,  447,  447,  447,  447,  448,  292,  448,

      448,  448,  448,  448,  448,  448,  448,  449,  291,  449,
      449,  449,  449,  449,  449,  449,  449,  290,  289,  288,
      284,  283,  282,  281,  278,  271,  270,  267,  264,  263,
      262,  261,  259,  257,  245,  244,  243,  242,  241,  240,
      227,  226,  224,  223,  222,  221,  220,  219,  218,  217,
      213,  212,  211,  210,  208,  207,  206,  205,  204,  203,
      202,  201,  200,  197,  194,  193,  177,  176,  173,  171,
      169,  168,  157,  153,  151,  147,  146,  144,  143,  142,
      141,  138,  137,  136,  135,  132,  130,  129,  128,  127,
      125,  124,  123,  122,  118,  117,  116,  115,  114,  113,

      111,  110,  109,  108,  107,  105,  101,   98,   93,   91,
       89,   85,   84,   83,   82,   81,   79,   74,   67,   62,
       58,   46,   45,   41,   40,   37,   36,   35,   29,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431,  431,  431,  431,  431,  431,  431,
      431,  431,  431,  431

    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "scanaut.ll"
/* -*- coding: utf-8 -*-
** Copyright (C) 2014-2018, 2020, 2021, 2022 Laboratoire de Recherche et Développement
** de l'Epita (LRDE).
**
** This file is part of Spot, a model checking library.
**
** Spot is free software; you can redistribute it and/or modify it
** under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 3 of the License, or
** (at your option) any later version.
**
** Spot is distributed in the hope that it will be useful, but WITHOUT
** ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
** or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
** License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
/* %option debug */

#line 39 "scanaut.ll"
#include <string>
#include <sys/stat.h>
#include <spot/parseaut/parsedecl.hh>
#include "spot/priv/trim.hh"

#define YY_USER_ACTION yylloc->columns(yyleng);

typedef hoayy::parser::token token;

struct extra_data
{
  unsigned comment_level = 0;
  unsigned parent_level = 0;
  int orig_cond = 0;
  bool lbtt_s = false;
  bool lbtt_t = false;
  unsigned lbtt_states = 0;
  bool yyin_close = true;
};

#line 1072 "scanaut.cc"

#line 1074 "scanaut.cc"

#define INITIAL 0
#define in_COMMENT 1
#define in_STRING 2
#define in_NEVER_PAR 3
#define in_HOA 4
#define in_NEVER 5
#define in_LBTT_HEADER 6
#define in_LBTT_STATE 7
#define in_LBTT_INIT 8
#define in_LBTT_TRANS 9
#define in_LBTT_T_ACC 10
#define in_LBTT_S_ACC 11
#define in_LBTT_GUARD 12
#define in_DSTAR 13

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#define YY_EXTRA_TYPE struct extra_data*

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    }; /* end struct yyguts_t */

static int yy_init_globals ( yyscan_t yyscanner );

int yylex_init (yyscan_t* scanner);

int yylex_init_extra ( YY_EXTRA_TYPE user_defined, yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( yyscan_t yyscanner );

int yyget_debug ( yyscan_t yyscanner );

void yyset_debug ( int debug_flag , yyscan_t yyscanner );

YY_EXTRA_TYPE yyget_extra ( yyscan_t yyscanner );

void yyset_extra ( YY_EXTRA_TYPE user_defined , yyscan_t yyscanner );

FILE *yyget_in ( yyscan_t yyscanner );

void yyset_in  ( FILE * _in_str , yyscan_t yyscanner );

FILE *yyget_out ( yyscan_t yyscanner );

void yyset_out  ( FILE * _out_str , yyscan_t yyscanner );

			int yyget_leng ( yyscan_t yyscanner );

char *yyget_text ( yyscan_t yyscanner );

int yyget_lineno ( yyscan_t yyscanner );

void yyset_lineno ( int _line_number , yyscan_t yyscanner );

int yyget_column  ( yyscan_t yyscanner );

void yyset_column ( int _column_no , yyscan_t yyscanner );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( yyscan_t yyscanner );
#else
extern int yywrap ( yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  , yyscan_t yyscanner);
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int , yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * , yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( yyscan_t yyscanner );
#else
static int input ( yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (yyscan_t yyscanner);

#define YY_DECL int yylex (yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
		}

		yy_load_buffer_state( yyscanner );
		}

	{
#line 71 "scanaut.ll"



#line 75 "scanaut.ll"
  std::string s;
  yylloc->step();

  auto parse_int = [&](){
    errno = 0;
    char* end;
    unsigned long n = strtoul(yytext, &end, 10);
    yylval->num = n;
    if (errno || yylval->num != n)
      {
        error_list.push_back(spot::parse_aut_error(*yylloc, "value too large"));
        yylval->num = 0;
      }
    return end;
  };



                        /* skip blanks and comments */
#line 1369 "scanaut.cc"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 432 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1030 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 94 "scanaut.ll"
yylloc->lines(yyleng); yylloc->step();
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 95 "scanaut.ll"
yylloc->lines(yyleng / 2); yylloc->step();
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 96 "scanaut.ll"
yylloc->step();
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 97 "scanaut.ll"
{
                          yyextra->orig_cond = YY_START;
			  BEGIN(in_COMMENT);
			  yyextra->comment_level = 1;
			}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 102 "scanaut.ll"
{
			    errno = 0;
			    char* end;
			    unsigned long n = strtoul(yytext + 5, &end, 10);
			    yylval->num = n;
			    if (errno || yylval->num != n)
                              {
			         error_list.push_back(spot::parse_aut_error(*yylloc, "value too large"));                             }
                            else if (error_list.empty())
                              {
			         char* beg = strchr(end, '"');
                                 end = strrchr(beg + 1, '"');
			         yylval->str = new std::string(beg + 1, end);
                                 yylloc->initialize(nullptr, n - 1, yylloc->begin.column);
                                 return token::LINEDIRECTIVE;
                              }
                            else
                              {
			         error_list.push_back(spot::parse_aut_error(*yylloc, "#line may not occur after any error"));
                              }
                          }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 123 "scanaut.ll"
BEGIN(in_HOA); return token::HOA;
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 124 "scanaut.ll"
BEGIN(INITIAL); throw spot::hoa_abort{*yylloc};
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 125 "scanaut.ll"
BEGIN(in_NEVER); return token::NEVER;
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 126 "scanaut.ll"
BEGIN(in_DSTAR); return token::DSA;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 127 "scanaut.ll"
BEGIN(in_DSTAR); return token::DRA;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 129 "scanaut.ll"
{
	                  BEGIN(in_LBTT_HEADER);
			  char* end = nullptr;
			  errno = 0;
			  unsigned long n = strtoul(yytext, &end, 10);
			  yylval->num = n;
			  unsigned s = end - yytext;
			  yylloc->end = yylloc->begin;
 			  yylloc->end.columns(s);
			  yyless(s);
			  if (errno || yylval->num != n)
			    {
                              error_list.push_back(
			        spot::parse_aut_error(*yylloc,
				  "value too large"));
			      yylval->num = 0;
                            }
                          yyextra->lbtt_states = yylval->num;
			  return token::LBTT;
			}
	YY_BREAK

case 12:
YY_RULE_SETUP
#line 151 "scanaut.ll"
return token::STATES;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 152 "scanaut.ll"
return token::START;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 153 "scanaut.ll"
return token::AP;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 154 "scanaut.ll"
return token::ALIAS;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 155 "scanaut.ll"
return token::ACCEPTANCE;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 156 "scanaut.ll"
return token::ACCNAME;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 157 "scanaut.ll"
return token::CONTROLLABLE_AP;
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 158 "scanaut.ll"
return token::TOOL;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 159 "scanaut.ll"
return token::NAME;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 160 "scanaut.ll"
return token::PROPERTIES;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 161 "scanaut.ll"
return token::SPOT_HIGHLIGHT_STATES;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 162 "scanaut.ll"
return token::SPOT_HIGHLIGHT_EDGES;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 163 "scanaut.ll"
return token::SPOT_STATE_PLAYER;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 164 "scanaut.ll"
return token::BODY;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 165 "scanaut.ll"
BEGIN(INITIAL); return token::END;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 166 "scanaut.ll"
return token::STATE;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 167 "scanaut.ll"
{
                          // For labels that do not span over several lines,
                          // we look them up in fmap to speed the construction
                          // of automata that use the same label multiple times.
                          std::string* s =
                              new std::string(yytext + 1, yyleng - 2);
                          if (auto i = fmap.find(*s); i != fmap.end())
                             {
                                delete s;
                                yylval->b = i->second.id();
                                return token::BDD;
                             }
                          yylval->str = s;
                          yylloc->end = yylloc->begin + 1;
                          yyless(1);
                          return *yytext;
                        }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 184 "scanaut.ll"
{
                          yylval->str = nullptr;
                          return *yytext;
                        }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 188 "scanaut.ll"
return *yytext;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 190 "scanaut.ll"
{
			   yylval->str = new std::string(yytext, yyleng);
			   return token::IDENTIFIER;
			}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 194 "scanaut.ll"
{
			   yylval->str = new std::string(yytext, yyleng - 1);
			   return token::HEADERNAME;
			}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 198 "scanaut.ll"
{
			   yylval->str = new std::string(yytext + 1, yyleng - 1);
			   return token::ANAME;
			}
	YY_BREAK
/* Handle short numbers without going through parse_int() for efficiency. */
case 34:
YY_RULE_SETUP
#line 203 "scanaut.ll"
yylval->num = *yytext - '0'; return token::INT;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 204 "scanaut.ll"
{
                          yylval->num = (yytext[0] * 10) + yytext[1] - '0' * 11;
                          return token::INT;
                        }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 208 "scanaut.ll"
parse_int(); return token::INT;
	YY_BREAK


case 37:
YY_RULE_SETUP
#line 212 "scanaut.ll"
return token::STATES;
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 213 "scanaut.ll"
return token::STATE;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 214 "scanaut.ll"
return token::START;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 215 "scanaut.ll"
return token::AP;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 216 "scanaut.ll"
return token::V2;
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 217 "scanaut.ll"
return token::EXPLICIT;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 218 "scanaut.ll"
yylloc->step();
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 219 "scanaut.ll"
yylloc->step();
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 220 "scanaut.ll"
return token::ACCPAIRS;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 221 "scanaut.ll"
return token::ACCSIG;
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 222 "scanaut.ll"
return token::ENDOFHEADER;
	YY_BREAK
/* Handle short numbers without going through parse_int() for efficiency. */
case 48:
YY_RULE_SETUP
#line 224 "scanaut.ll"
yylval->num = *yytext - '0'; return token::INT;
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 225 "scanaut.ll"
{
                          yylval->num = (yytext[0] * 10) + yytext[1] - '0' * 11;
                          return token::INT;
                        }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 229 "scanaut.ll"
parse_int(); return token::INT;
	YY_BREAK
/* The start of any automaton is the end of this one.
     We do not try to detect LBTT automata, as that would
     be too hard to distinguish from state numbers. */
case 51:
/* rule 51 can match eol */
YY_RULE_SETUP
#line 233 "scanaut.ll"
{
			  yylloc->end = yylloc->begin;
			  yyless(0);
			  BEGIN(INITIAL);
			  return token::ENDDSTAR;
			}
	YY_BREAK
case YY_STATE_EOF(in_DSTAR):
#line 239 "scanaut.ll"
return token::ENDDSTAR;
	YY_BREAK


case 52:
YY_RULE_SETUP
#line 243 "scanaut.ll"
return token::SKIP;
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 244 "scanaut.ll"
return token::IF;
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 245 "scanaut.ll"
return token::FI;
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 246 "scanaut.ll"
return token::DO;
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 247 "scanaut.ll"
return token::OD;
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 248 "scanaut.ll"
return token::ARROW;
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 249 "scanaut.ll"
return token::GOTO;
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 250 "scanaut.ll"
return token::FALSE;
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 251 "scanaut.ll"
return token::ATOMIC;
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 252 "scanaut.ll"
return token::ASSERT;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 254 "scanaut.ll"
{
			  yyextra->parent_level = 1;
			  BEGIN(in_NEVER_PAR);
			  yylval->str = new std::string(yytext, yyleng);
			}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 260 "scanaut.ll"
{
                          yylval->str = new std::string(yytext, yyleng);
			  return token::FORMULA;
                        }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 265 "scanaut.ll"
{
			  yylval->str = new std::string(yytext, yyleng);
	                  return token::IDENTIFIER;
		        }
	YY_BREAK

/* Note: the LBTT format is scanf friendly, but not Bison-friendly.
     If we only tokenize it as a stream of INTs, the parser will have
     a very hard time recognizing what is a state from what is a
     transitions.  As a consequence we abuse the start conditions to
     maintain a state an return integers with different semantic types
     depending on the purpose of those integers. */

case 65:
YY_RULE_SETUP
#line 278 "scanaut.ll"
{
			  BEGIN(in_LBTT_STATE);
                          auto end = parse_int();
			  yyextra->lbtt_s = false;
			  yyextra->lbtt_t = false;
			  if (end)
			    while (int c = *end++)
			      {
			         if (c == 's')
			           yyextra->lbtt_s = true;
			         else // c == 't'
			           yyextra->lbtt_t = true;
			      }
  		          if (!yyextra->lbtt_t)
			    yyextra->lbtt_s = true;
			  if (yyextra->lbtt_states == 0)
			    {
                              BEGIN(INITIAL);
                              return token::LBTT_EMPTY;
			    }
			  if (yyextra->lbtt_s && !yyextra->lbtt_t)
			    return token::INT_S;
			  else
			    return token::INT;
			}
	YY_BREAK

case 66:
YY_RULE_SETUP
#line 305 "scanaut.ll"
{
                           parse_int();
			   BEGIN(in_LBTT_INIT);
			   return token::STATE_NUM;
			}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 310 "scanaut.ll"
{
                           yylval->num = *yytext - '0';
			   if (yyextra->lbtt_s)
			      BEGIN(in_LBTT_S_ACC);
			   else
			      BEGIN(in_LBTT_TRANS);
			   return token::INT;
			}
	YY_BREAK

case 68:
YY_RULE_SETUP
#line 319 "scanaut.ll"
parse_int(); return token::ACC;
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 320 "scanaut.ll"
BEGIN(in_LBTT_TRANS); yylloc->step();
	YY_BREAK


case 70:
YY_RULE_SETUP
#line 323 "scanaut.ll"
{
			  parse_int();
			  if (yyextra->lbtt_t)
			    BEGIN(in_LBTT_T_ACC);
			  else
			    BEGIN(in_LBTT_GUARD);
			  return token::DEST_NUM;
			}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 331 "scanaut.ll"
{
                          if (--yyextra->lbtt_states)
			    {
			       BEGIN(in_LBTT_STATE);
			       yylloc->step();
			    }
			  else
			    {
			       BEGIN(INITIAL);
			       return token::ENDAUT;
			    }
			}
	YY_BREAK


case 72:
YY_RULE_SETUP
#line 345 "scanaut.ll"
parse_int(); return token::ACC;
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 346 "scanaut.ll"
BEGIN(in_LBTT_GUARD); yylloc->step();
	YY_BREAK


case 74:
YY_RULE_SETUP
#line 349 "scanaut.ll"
{
  			  yylval->str = new std::string(yytext, yyleng);
			  BEGIN(in_LBTT_TRANS);
 			  return token::STRING;
			}
	YY_BREAK


case 75:
YY_RULE_SETUP
#line 358 "scanaut.ll"
++yyextra->comment_level;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 359 "scanaut.ll"
continue;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 360 "scanaut.ll"
continue;
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 361 "scanaut.ll"
continue;
	YY_BREAK
case 79:
/* rule 79 can match eol */
YY_RULE_SETUP
#line 362 "scanaut.ll"
yylloc->lines(yyleng); yylloc->end.column = 1;
	YY_BREAK
case 80:
/* rule 80 can match eol */
YY_RULE_SETUP
#line 363 "scanaut.ll"
yylloc->lines(yyleng / 2); yylloc->end.column = 1;
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 364 "scanaut.ll"
{
			  if (--yyextra->comment_level == 0)
			    {
			      yylloc->step();
                              int oc = yyextra->orig_cond;
		              BEGIN(oc);
		            }
                        }
	YY_BREAK
case YY_STATE_EOF(in_COMMENT):
#line 372 "scanaut.ll"
{
                           int oc = yyextra->orig_cond;
	                   BEGIN(oc);
                           error_list.push_back(
			     spot::parse_aut_error(*yylloc,
			       "unclosed comment"));
			   return 0;
                        }
	YY_BREAK

/* matched late, so that the in_LBTT_GUARD pattern has precedence */
case 82:
YY_RULE_SETUP
#line 383 "scanaut.ll"
{
                          yyextra->orig_cond = YY_START;
			  BEGIN(in_STRING);
			  yyextra->comment_level = 1;
			}
	YY_BREAK

case 83:
YY_RULE_SETUP
#line 390 "scanaut.ll"
{
                           int oc = yyextra->orig_cond;
                           BEGIN(oc);
			   yylval->str = new std::string(s);
			   return token::STRING;
 			}
	YY_BREAK
case 84:
/* rule 84 can match eol */
YY_RULE_SETUP
#line 396 "scanaut.ll"
{
  			  s.append(yytext, yyleng);
                          yylloc->lines(yyleng); yylloc->end.column = 1;
			}
	YY_BREAK
case 85:
/* rule 85 can match eol */
YY_RULE_SETUP
#line 400 "scanaut.ll"
{
  			  s.append(yytext, yyleng);
                          yylloc->lines(yyleng / 2); yylloc->end.column = 1;
			}
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 404 "scanaut.ll"
s += yytext[1];
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 405 "scanaut.ll"
s.append(yytext, yyleng);
	YY_BREAK
case YY_STATE_EOF(in_STRING):
#line 406 "scanaut.ll"
{
                           error_list.push_back(
			     spot::parse_aut_error(*yylloc,
			       "unclosed string"));
                           int oc = yyextra->orig_cond;
                           BEGIN(oc);
			   yylval->str = new std::string(s);
			   return token::STRING;
                        }
	YY_BREAK


case 88:
YY_RULE_SETUP
#line 418 "scanaut.ll"
{
			  ++yyextra->parent_level;
			  yylval->str->append(yytext, yyleng);
			}
	YY_BREAK
/* if we match ")&&(" or ")||(", stay in <in_NEVER_PAR> mode */
case 89:
YY_RULE_SETUP
#line 423 "scanaut.ll"
{
	                  yylval->str->append(yytext, yyleng);
			}
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 426 "scanaut.ll"
{
	                  yylval->str->append(yytext, yyleng);
			  if (!--yyextra->parent_level)
			    {
                              BEGIN(in_NEVER);
			      spot::trim(*yylval->str);
			      return token::FORMULA;
			    }
			}
	YY_BREAK
case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 435 "scanaut.ll"
{
                          yylval->str->append(yytext, yyleng);
			  yylloc->lines(yyleng); yylloc->end.column = 1;
			}
	YY_BREAK
case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 439 "scanaut.ll"
{
			  yylval->str->append(yytext, yyleng);
  			  yylloc->lines(yyleng / 2); yylloc->end.column = 1;
			}
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 443 "scanaut.ll"
yylval->str->append(yytext, yyleng);
	YY_BREAK
case YY_STATE_EOF(in_NEVER_PAR):
#line 444 "scanaut.ll"
{
                          error_list.push_back(
			    spot::parse_aut_error(*yylloc,
 			      "missing closing parenthese"));
                          yylval->str->append(yyextra->parent_level, ')');
                          BEGIN(in_NEVER);
			  spot::trim(*yylval->str);
			  return token::FORMULA;
			}
	YY_BREAK

case 94:
YY_RULE_SETUP
#line 455 "scanaut.ll"
return *yytext;
	YY_BREAK

  /* Dummy use of yyunput to shut up a gcc warning.  */
  (void) &yyunput;

case 95:
YY_RULE_SETUP
#line 462 "scanaut.ll"
ECHO;
	YY_BREAK
#line 2178 "scanaut.cc"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(in_HOA):
case YY_STATE_EOF(in_NEVER):
case YY_STATE_EOF(in_LBTT_HEADER):
case YY_STATE_EOF(in_LBTT_STATE):
case YY_STATE_EOF(in_LBTT_INIT):
case YY_STATE_EOF(in_LBTT_TRANS):
case YY_STATE_EOF(in_LBTT_T_ACC):
case YY_STATE_EOF(in_LBTT_S_ACC):
case YY_STATE_EOF(in_LBTT_GUARD):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( yywrap( yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  , yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size , yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 432 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	char *yy_cp = yyg->yy_c_buf_p;

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 432 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 431);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

    static void yyunput (int c, char * yy_bp , yyscan_t yyscanner)
{
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = yyg->yy_n_chars + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr);
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin , yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap( yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE , yyscanner);
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file , yyscanner);
	yy_load_buffer_state( yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state( yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2) , yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file , yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf , yyscanner );

	yyfree( (void *) b , yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_flush_buffer( b , yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state( yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack(yyscanner);

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state( yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER , yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state( yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state ) , yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b , yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr , yyscan_t yyscanner)
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) , yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n , yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n , yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

/* User-visible API */

/* yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */
int yylex_init(yyscan_t* ptr_yy_globals)
{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* yylex_init_extra has the same functionality as yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to yyalloc in
 * the yyextra field.
 */
int yylex_init_extra( YY_EXTRA_TYPE yy_user_defined, yyscan_t* ptr_yy_globals )
{
    struct yyguts_t dummy_yyguts;

    yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    yyset_extra (yy_user_defined, *ptr_yy_globals);

    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER , yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	yyfree(yyg->yy_buffer_stack , yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        yyfree( yyg->yy_start_stack , yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 462 "scanaut.ll"


namespace spot
{
  void
  hoayyreset(yyscan_t yyscanner)
  {
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    BEGIN(INITIAL);
    yyextra->comment_level = 0;
    yyextra->parent_level = 0;
  }

  int
  hoayyopen(const std::string &name, yyscan_t* scanner)
  {
    yylex_init_extra(new extra_data, scanner);
    yyscan_t yyscanner = *scanner;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    bool want_interactive = false;

    // yy_flex_debug = 1;
    if (name == "-")
      {
        // If the input is a pipe, make the scanner
        // interactive so that it does not wait for the input
        // buffer to be full to process automata.
        struct stat s;
        if (fstat(fileno(stdin), &s) < 0)
           throw std::runtime_error("fstat failed");
	if (S_ISFIFO(s.st_mode))
	  want_interactive = true;

        yyin = stdin;
        yyextra->yyin_close = false;
      }
    else
      {
        yyin = fopen(name.c_str(), "r");
        if (!yyin)
	  return 1;
        yyextra->yyin_close = true;
      }

    if (want_interactive)
      yy_set_interactive(1);
    return 0;
  }

  int
  hoayystring(const char* data, yyscan_t* scanner)
  {
    yylex_init_extra(new extra_data, scanner);
    yy_scan_string(data, *scanner);
    return 0;
  }

  int
  hoayyopen(int fd, yyscan_t* scanner)
  {
    yylex_init_extra(new extra_data, scanner);
    yyscan_t yyscanner = *scanner;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    bool want_interactive = false;
    yyextra->yyin_close = false;

    yyin = fdopen(fd, "r");

    if (!yyin)
      throw std::runtime_error("fdopen failed");

    // If the input is a pipe, make the scanner
    // interactive so that it does not wait for the input
    // buffer to be full to process automata.
    struct stat s;
    if (fstat(fd, &s) < 0)
      throw std::runtime_error("fstat failed");
    if (S_ISFIFO(s.st_mode))
      want_interactive = true;

    if (want_interactive)
      yy_set_interactive(1);
    return 0;
  }

  void
  hoayyclose(yyscan_t yyscanner)
  {
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    if (yyin)
      {
        if (yyextra->yyin_close)
          fclose(yyin);
        yyin = NULL;
      }
    delete yyextra;
    yylex_destroy(yyscanner);
  }
}

